@@ -997,15 +997,15 @@ class DatabaseManager:
 
 
     @property
-    def schemas(self):
+    def schemas(self)->_Iterable[dict]:
         '''
             Get the list of schemas in this database.
 
             ----------
 
-            Return {str|None}
+            Return {list}
             ----------------------
-            The sql json summary file path if it exists.
+            A list of schema data dictionaries
 
             Meta
             ----------
