@@ -23,6 +23,10 @@ from lxml import etree as _etree
 import utils.file_utils as _f
 import utils.dict_utils as _obj
 import utils.string_utils as _csu
+
+
+from config import _nodebase_type,_diagram_type,_drawing_type,_Iterable
+
 from utils.drawio.nodeBase import NodeBase as _NodeBase
 # from utils.drawio.diagram import Diagram as Diagram
 import utils.drawio.diagram_utils as _dia
@@ -266,7 +270,7 @@ class Connector(_NodeBase):
     '''
 
 
-    def __init__(self,tree:_etree,element=None,diagram:Diagram=None):
+    def __init__(self,tree:_etree,element=None,diagram:_diagram_type=None):
         super().__init__(tree,element,diagram)
         self.settings = {}
         self.data = {
